import { ValidationError } from 'class-validator';
import { eCheckResult, eLCID } from '../../../../consts';
import { AllowPrimitives } from '../../../../types';
/**
* Single text field value with check result
*/
export interface iRTextFieldValue {
    /**
    * Value of the text field
    * @type {string}
    */
    value: string;
    /**
    * Status of check
    * @type {eCheckResult}
    */
    status: eCheckResult;
    /**
    * LCID
    * @type {eLCID}
    */
    lcid: eLCID;
}
/**
* Single text field value with check result
*/
export declare class RTextFieldValue implements iRTextFieldValue {
    /**
    * Value of the text field
    * @type {string}
    */
    value: string;
    /**
    * Status of check
    * @type {eCheckResult}
    */
    status: eCheckResult;
    lcid: eLCID;
    /**
    * Create instance of RTextFieldValue from plain object
    * @param {AllowPrimitives<iRTextFieldValue>} input
    * @returns {RTextFieldValue}
    */
    static fromPlain: (input: AllowPrimitives<iRTextFieldValue>) => RTextFieldValue;
    /**
    * Check if input is valid
    * @param {RTextFieldValue} input
    * @returns {boolean}
    */
    static getValidationErrors: (input: RTextFieldValue) => ValidationError[];
    /**
    * Check if input is valid
    * @param {RTextFieldValue | RTextFieldValue[]} input - Array of RTextFieldValue or single RTextFieldValue
    * @returns {boolean}
    */
    static isValid: (input: RTextFieldValue | RTextFieldValue[]) => boolean;
}
